@@ -16,9 +16,9 @@ use super::*;
 
 use RenderFormat::{MaxOrReadableSize, PageReadableSize, Precision, ReadableSize};
 
-impl HasRenderConfig for model::CgroupModel {
+impl HasRenderConfig for model::SingleCgroupModel {
     fn get_render_config_builder(field_id: &Self::FieldId) -> RenderConfigBuilder {
-        use model::CgroupModelFieldId::*;
+        use model::SingleCgroupModelFieldId::*;
         let rc = RenderConfigBuilder::new();
         match field_id {
             Name => rc.title("Name").width(50),
@@ -26,6 +26,9 @@ impl HasRenderConfig for model::CgroupModel {
             InodeNumber => rc.title("Inode Number"),
             Cpu(field_id) => model::CgroupCpuModel::get_render_config_builder(field_id),
             Io(field_id) => model::CgroupIoModel::get_render_config_builder(field_id),
+            IoDetails(field_id) => {
+                model::CgroupIoModel::get_render_config_builder(&field_id.subquery_id)
+            }
             Mem(field_id) => model::CgroupMemoryModel::get_render_config_builder(field_id),
             Pressure(field_id) => model::CgroupPressureModel::get_render_config_builder(field_id),
         }
@@ -135,6 +138,9 @@ impl HasRenderConfig for model::NetworkModel {
     fn get_render_config_builder(field_id: &Self::FieldId) -> RenderConfigBuilder {
         use model::NetworkModelFieldId::*;
         match field_id {
+            Interfaces(field_id) => {
+                model::SingleNetModel::get_render_config_builder(&field_id.subquery_id)
+            }
             Tcp(field_id) => model::TcpModel::get_render_config_builder(field_id),
             Ip(field_id) => model::IpModel::get_render_config_builder(field_id),
             Ip6(field_id) => model::Ip6Model::get_render_config_builder(field_id),
@@ -403,6 +409,9 @@ impl HasRenderConfig for model::SystemModel {
             Cpus(field_id) => Vec::<model::SingleCpuModel>::get_render_config_builder(field_id),
             Mem(field_id) => model::MemoryModel::get_render_config_builder(field_id),
             Vm(field_id) => model::VmModel::get_render_config_builder(field_id),
+            Disks(field_id) => {
+                model::SingleDiskModel::get_render_config_builder(&field_id.subquery_id)
+            }
         }
     }
 }
@@ -446,9 +455,15 @@ impl HasRenderConfig for model::SingleCpuModel {
 impl HasRenderConfig for Vec<model::SingleCpuModel> {
     fn get_render_config_builder(field_id: &Self::FieldId) -> RenderConfigBuilder {
         let mut rc = model::SingleCpuModel::get_render_config_builder(&field_id.subquery_id).get();
-        rc.title = rc
-            .title
-            .map(|title| format!("CPU {} {}", field_id.idx, title));
+        rc.title = rc.title.map(|title| {
+            format!(
+                "CPU {} {}",
+                field_id
+                    .idx
+                    .expect("VecFieldId without idx should not have render config"),
+                title
+            )
+        });
         rc.into()
     }
 }
